package Bundle::Net::SXIP::Homesite;

use warnings;
use strict;

our $VERSION = '1.0.1';

1; # End of Bundle::Net::SXIP::Homesite

__END__

=head1 NAME

Bundle::Net::SXIP::Homesite

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Net::SXIP::Homesite'

=head1 CONTENTS

CGI::Session

Class::DBI::mysql

Digest::HMAC_SHA1

Digest::MD5

Digest::SHA1

Error

HTML::FillInForm

HTTP::Date

Iterator

Module::Pluggable

Net::SXIP::Digest

Spiffy

Template

Test::More

Time::Piece::MySQL

UNIVERSAL::require

URI

YAML

=head1 DESCRIPTION

This bundle defines all prerequisites for Sxip's Perl Homesite.

=head1 SEE ALSO

L<CPAN/Bundles>

